from __future__ import absolute_import
from .sweeper import file_dups, mv_file_dups, rm_file_dups, iter_file_dups

__all__ = ['file_dups', 'mv_file_dups', 'rm_file_dups', 'iter_file_dups']
